@@ -241,7 +241,7 @@ aws.gaussian <- function(y,
             mgp = c(2, 1, 0)
           )
           image(array(y,dy),
-                col = gray((0:255) / 255),
+                col = grey((0:255) / 255),
                 xaxt = "n",
                 yaxt = "n")
           title(paste(
@@ -252,7 +252,7 @@ aws.gaussian <- function(y,
           ))
           image(
             array(tobj$theta,dy),
-            col = gray((0:255) / 255),
+            col = grey((0:255) / 255),
             xaxt = "n",
             yaxt = "n"
           )
@@ -266,7 +266,7 @@ aws.gaussian <- function(y,
           ))
           image(
             array(tobj$bi,dy),
-            col = gray((0:255) / 255),
+            col = grey((0:255) / 255),
             xaxt = "n",
             yaxt = "n"
           )
@@ -286,7 +286,7 @@ aws.gaussian <- function(y,
             mgp = c(2, 1, 0)
           )
           image(array(y,dy)[, , n3 %/% 2 + 1],
-                col = gray((0:255) / 255),
+                col = grey((0:255) / 255),
                 xaxt = "n",
                 yaxt = "n")
           title(paste(
@@ -297,7 +297,7 @@ aws.gaussian <- function(y,
           ))
           image(
             array(tobj$theta,dy)[, , n3 %/% 2 + 1],
-            col = gray((0:255) / 255),
+            col = grey((0:255) / 255),
             xaxt = "n",
             yaxt = "n"
           )
@@ -311,7 +311,7 @@ aws.gaussian <- function(y,
           ))
           image(
             array(tobj$bi,dy)[, , n3 %/% 2 + 1],
-            col = gray((0:255) / 255),
+            col = grey((0:255) / 255),
             xaxt = "n",
             yaxt = "n"
           )
